@@ -182,7 +182,7 @@ fn build_implib_file(
     target: &target::Target,
     targetdir: &Path,
 ) -> anyhow::Result<()> {
-    if target.os == "windows" {
+    if target.os == "windows" || target.os == "cygwin" {
         ws.gctx().shell().status("Building", "implib")?;
 
         let def_path = targetdir.join(format!("{name}.def"));
@@ -674,7 +674,7 @@ fn load_manifest_capi_config(
                         .ok()
                         .is_some_and(|p| p.matches(name, &rustc_target.cfg))
                     {
-                        v.as_str()
+                        v.get("rustflags").and_then(|v| v.as_str())
                     } else {
                         None
                     }
